#
# spec file for package bzip2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libbz2-1
Name:           bzip2
Version:        1.0.6
Release:        115.31
Summary:        A Program for Compressing Files
License:        BSD-3-Clause
Group:          Productivity/Archiving/Compression
URL:            https://sourceware.org/bzip2
Source:         %{name}-%{version}.tar.gz
Source1:        bznew.gz
Source2:        bznew.1.gz
Source3:        baselibs.conf
Source100:      bzip2-rpmlintrc
# PATCH-FEATURE-OPENSUSE bzip2-1.0.6-autoconfiscated.patch sbrabec@suse.cz -- Convert to a standard autoconf based package.
Patch0:         ftp://ftp.suse.com/pub/people/sbrabec/bzip2/for_downstream/bzip2-1.0.6.2-autoconfiscated.patch
Patch1:         bzip2-1.0.6-fix-bashisms.patch
Patch2:         bzip2-unsafe_strcpy.patch
Patch3:         bzip2-point-to-doc-pkg.patch
Patch4:         bzip2-ocloexec.patch
# PATCH-FIX-UPSTREAM bnc#970260 kstreitova@suse.com -- fix a wrong exit code when grepping multiple archives
Patch5:         bzip2-1.0.6-bzgrep_return_value.patch
BuildRequires:  autoconf >= 2.57
BuildRequires:  libtool
BuildRequires:  pkgconfig
# The following is a kludge to get updating bzip2 to after the split work
Requires(pre):  %{libname}
Provides:       bzip = %{version}
Obsoletes:      bzip < %{version}

%description
The bzip2 program is a very powerful program for compressing files.

%package doc
Summary:        The bzip2 program and Library Documentation
Group:          Productivity/Archiving/Compression
BuildArch:      noarch

%description doc
The bzip2 program and library documentation.

%package -n %{libname}
Summary:        The bzip2 runtime library
Group:          System/Libraries

%description -n %{libname}
The bzip2 runtime library

%package -n libbz2-devel
Summary:        The bzip2 runtime library development files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel

%description -n libbz2-devel
The bzip2 runtime library development files.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2
%patch3 -p1
%patch4
%patch5 -p1

%build
autoreconf -fiv
%configure \
  --with-pic \
  --disable-static
%if 0%{?do_profiling}
  make %{?_smp_mflags} CFLAGS="%{optflags} %{cflags_profile_generate}"
  make %{?_smp_mflags} CFLAGS="%{optflags} %{cflags_profile_generate}" test
  make clean
  make %{?_smp_mflags} CFLAGS="%{optflags} %{cflags_profile_feedback}"
%else
  make %{?_smp_mflags} CFLAGS="%{optflags}"
%endif

%install
%make_install pkgconfigdir=%{_libdir}/pkgconfig
gzip -9 manual.ps
gzip -dc %{SOURCE1} > bznew
install -Dpm 0755 bznew %{buildroot}%{_bindir}/bznew
install -m 0644 %{SOURCE2} %{buildroot}%{_mandir}/man1
# Steam and prolly others still use the 1.0 name, so we need to be
# compatible
# Remove this when all distros use the autotools based bzip2 release
ln -s libbz2.so.1 %{buildroot}/%{_libdir}/libbz2.so.1.0

find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname}  -p /sbin/ldconfig

%check
make %{?_smp_mflags} test

%files
%{_bindir}/bunzip2
%{_bindir}/bzcat
%{_bindir}/bzcmp
%{_bindir}/bzdiff
%{_bindir}/bzegrep
%{_bindir}/bzfgrep
%{_bindir}/bzgrep
%{_bindir}/bzip2
%{_bindir}/bzip2recover
%{_bindir}/bzless
%{_bindir}/bzmore
%{_bindir}/bznew
%{_mandir}/man1/bunzip2.1%{?ext_man}
%{_mandir}/man1/bzcat.1%{?ext_man}
%{_mandir}/man1/bzcmp.1%{?ext_man}
%{_mandir}/man1/bzdiff.1%{?ext_man}
%{_mandir}/man1/bzegrep.1%{?ext_man}
%{_mandir}/man1/bzfgrep.1%{?ext_man}
%{_mandir}/man1/bzgrep.1%{?ext_man}
%{_mandir}/man1/bzip2.1%{?ext_man}
%{_mandir}/man1/bzless.1%{?ext_man}
%{_mandir}/man1/bzmore.1%{?ext_man}
%{_mandir}/man1/bznew.1%{?ext_man}

%files doc
%doc manual.ps.gz manual*.html bzip2.txt manual.pdf

%files -n %{libname}
%{_libdir}/libbz2.so.*

%files -n libbz2-devel
%license LICENSE
%doc CHANGES
%{_includedir}/bzlib.h
%{_libdir}/libbz2.so
%{_libdir}/pkgconfig/bzip2.pc

%changelog
* Tue Aug 21 2018 christophe@krop.fr
- Replace the URL. The bzip.org owner changed [bsc#1104445].
- Remove the URL from the 'Source' line. The 1.0.6 version is not
  available.
- Run spec-cleaner.
* Wed Feb 28 2018 tchvatal@suse.com
- Update autotools patchset:
  D bzip2-1.0.6-autoconfiscated.patch
  A bzip2-1.0.6.2-autoconfiscated.patch
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Sat Nov  4 2017 bwiedemann@suse.com
- Fix build on Fedora and Mageia
* Tue Oct 31 2017 sbrabec@suse.com
- Update bzip2-1.0.6-autoconfiscated.patch:
  * Bump version to 1.0.6.
  * Fix script symlinks on platforms with EXEEXT.
* Tue Jun  6 2017 mpluskal@suse.com
- Drop implicit pie building
- Try profiled build
- Move autoreconf to build section
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
* Thu Mar 24 2016 kstreitova@suse.com
- add bzip2-1.0.6-bzgrep_return_value.patch to fix bzgrep wrapper
  that always returns 0 as an exit code when grepping multiple
  archives [bsc#970260]
* Wed Jan 13 2016 idonmez@suse.com
- Remove bzip2-faster.patch, it causes a crash with libarchive and
  valgrind points out uninitialized memory. See
  https://github.com/libarchive/libarchive/issues/637#issuecomment-170612576
* Thu Jan  8 2015 olaf@aepfle.de
- Avoid noarch sub package in SLE_11
* Mon Dec 29 2014 tchvatal@suse.com
- Cleanup a bit.
- Remove the profiling stuff as it should not be used nowdays.
  At least even factory builds without it.
- Provide libbz2.so.1.0 as other distros do, so we can run tiny
  things like steam.
- Respect cflags again, borked by previous commit.
* Fri Dec 19 2014 meissner@suse.com
- build with PIE
* Mon Nov  3 2014 ledest@gmail.com
- fix basisms in bzgrep and bznew
- add patches:
  * bzip2-1.0.6-fix-bashisms.patch
* Tue Sep  2 2014 vcizek@suse.com
- revert the bzip2-handle_pipe_input_with-f_option.patch because it
  breaks other programs using the bzip2 library
* Wed Aug  6 2014 idonmez@suse.com
- Implement %%check
* Tue Aug  5 2014 vcizek@suse.com
- handle pipe input with the -f option (bnc#884004)
  * added bzip2-handle_pipe_input_with-f_option.patch
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Thu Mar 21 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Jan 21 2013 idonmez@suse.com
- Add %%{version} to Obsoletes/Provides
* Mon Jan 21 2013 jengelh@inai.de
- Executing autoreconf requires autoconf
- Set RPM groups to the common ones we use for library and
  "-devel" packages
* Sun Feb 12 2012 crrodriguez@opensuse.org
- Put libraries back into %%{_libdir}, /usr merge project.
* Thu Jan 26 2012 sitter@kde.org
- Drop bzip2-maxlen20.patch as pre-2005 compatibility should not
  be a concern anymore.
* Sat Jan  7 2012 crrodriguez@opensuse.org
- bzlib: open file descriptors with O_CLOEXEC, but just like
  the zlib case, only when bzopen() is used and not bzdopen()
  to avoid messing up with the caller's semantics.
  It is responsability of to initiator to set that flag in such case.
- Replace error prone list of exported symbols with proper use of
  GCC visibility features.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug 10 2011 puzel@novell.com
- package all documentation files referenced by README; also
  point to bzip2-doc package (bnc#709260)
* Tue Jul 26 2011 jengelh@medozas.de
- Update baselibs.conf to ship libbz2-devel-32bit
* Mon Nov 29 2010 cristian.rodriguez@opensuse.org
- extend bzip2-1.0.6-autoconfiscated.patch to support
  an LD version script so we export only public symbols
* Wed Nov  3 2010 puzel@novell.com
- use new version of autoconfiscate patch (by sbrabec)
* Thu Sep 23 2010 puzel@novell.com
- update to bzip2-1.0.6
  - fixes CVE-2010-0405
- drop bzip2-CVE-2010-0405 (upstream)
* Tue Sep 21 2010 puzel@novell.com
- add bzip2-CVE-2010-0405.patch (bnc#636978)
- fix copy-paste error in profile_bzip2()
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Dec 16 2009 jengelh@medozas.de
- package documentation as noarch
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov 24 2009 sbrabec@suse.cz
- Package migrated to autoconf.
* Sun Jun  7 2009 crrodriguez@suse.de
- remove static libraries see bnc#509945 for details
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Aug  1 2008 jw@suse.de
- added missing header to bznew [bnc#413261]
* Wed May 14 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 lmichnovic@suse.cz
- update to version 1.5
  * Fixes CERT-FI 20469 as it applies to bzip2
  which obsoletes bzip2-CVE-2008-1372-CERT-FI-20469.patch
- installing scripts bzdiff, bzgrep, bzmore
  and symlinks bzless, bzcmp [bnc#376464]
- addded CFLAGS in Makefile-libbz2_so (cflags.patch)
- fix unsafe strcpy in bzip2recover (unsafe_strcpy.patch)
  Thanks to Red Hat.
* Wed Mar 19 2008 nadvornik@suse.cz
- fixed buffer overflows CVE-2008-1372 [bnc#372047]
* Thu Dec  6 2007 lmichnovic@suse.cz
- bznew can now repack also .tar.gz files [#342612]
  The dot in suffix is explicitly checked
* Thu Nov  8 2007 lmichnovic@suse.cz
- added README, LICENSE, CHANGES files to libbz2-1 package
* Sun Jun  3 2007 schwab@suse.de
- Fix dependency.
* Wed May 30 2007 lmichnovic@suse.cz
- renamed lib to libbz2-1 according to Shared Library Packaging
  Policy
- calling ldconfig for libbz2-1 package
* Fri May 25 2007 dmueller@suse.de
- build with profile feedback enabled (7-15%% speedup)
* Fri Mar 30 2007 rguenther@suse.de
- Add PreReq to libbz2 from bzip2 to work around update problems
* Fri Mar 23 2007 rguenther@suse.de
- Split off doc, libbz2 and libbz2-devel packages
* Mon Jan 15 2007 lmichnovic@suse.cz
- Update to version 1.0.4
  * Fixes some minor bugs since the last version, 1.0.3.
  * Fix file permissions race problem (CAN-2005-0953).
  * Avoid possible segfault in BZ2_bzclose.  From Coverity's NetBSD
    scan.
  * 'const'/prototype cleanups in the C code.
  * Change default install location to /usr/local, and handle
    multiple 'make install's without error.
  * Sanitise file names more carefully in bzgrep.  Fixes
    CAN-2005-0758 to the extent that applies to bzgrep.
  * Use 'mktemp' rather than 'tempfile' in bzdiff.
  * Tighten up a couple of assertions in blocksort.c following
    automated analysis.
  * Fix minor doc/comment bugs.
* Mon Oct 16 2006 dmueller@suse.de
- strip .la files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 schwab@suse.de
- Don't strip binaries.
* Fri Aug 12 2005 mls@suse.de
- make decompress much faster
- compile with -O3
- go back to maxlen=20 when compressing
* Thu Aug  4 2005 ro@suse.de
- next libdir: only package lib*
* Thu Aug  4 2005 ro@suse.de
- do not package all of libdir (debuginfo)
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.0.3
* Tue Jun 28 2005 kukuk@suse.de
- Move shared libraries to /%%{_lib}
* Thu Mar 24 2005 werner@suse.de
- Add bznew, a changeed version of the gzip znew.
* Tue Apr 20 2004 mmj@suse.de
- Fix strict aliasing
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Wed Jul 23 2003 tcrhak@suse.cz
- fixed URL
* Tue Jul 23 2002 tcrhak@suse.cz
- renamed to bzip2
* Tue Feb  5 2002 tcrhak@suse.cz
- update to version 1.0.2
- bziped tarball
* Thu Mar  8 2001 nadvornik@suse.cz
- re-added /usr/include/bzlib.h
* Thu Mar  8 2001 bk@suse.de
- Replaced the -malign options with -mcpu=pentiumpro
* Tue Mar  6 2001 bk@suse.de
- add version info to libbz2 link to fix the library version number
- if i386, add -malign-loops=2 -malign-jumps=2 -malign-functions=2
* Thu Nov 30 2000 aj@suse.de
- New version, compile with LFS support.
* Tue Oct  3 2000 kukuk@suse.de
- Set libdir for 64bit architectures
* Mon May 22 2000 nadvornik@suse.cz
- update to 1.0.0
* Wed Apr 26 2000 nadvornik@suse.cz
- changed Group
* Mon Apr 10 2000 nadvornik@suse.cz
- added URL
* Tue Apr  4 2000 nadvornik@suse.cz
- fixed to compile
* Mon Apr  3 2000 bk@suse.de
- added libbz2 shared library support for s390
* Thu Mar  2 2000 fehr@suse.de
- moved man pages to /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Sep 13 1999 fehr@suse.de
- update to 0.9.5d
* Thu Jul  1 1999 ro@suse.de
- update to 0.9.0c
* Fri Sep 18 1998 ro@suse.de
- update to 0.9.0b (including libbz2 and bzlib.h)
* Thu Oct 30 1997 fehr@suse.de
- add bzip package to S.u.S.E. distribution
